@@ -1,4 +1,4 @@
-# $Id$
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Fill/LinearGradient.pm 67466 2008-07-30T01:53:50.528367Z daisuke  $
 
 package Google::Chart::Fill::LinearGradient;
 use Moose;
@@ -33,40 +33,27 @@ has 'angle' => (
     required => 1
 );
 
-has 'color1' => (
+has 'color' => (
     is => 'rw',
     isa => 'Google::Chart::Color::Data',
     required => 1
 );
 
-has 'color2' => (
-    is => 'rw',
-    isa => 'Google::Chart::Color::Data',
-    required => 1
-);
-
-has 'offset1' => (
+has 'offset' => (
     is => 'rw',
     isa => 'Google::Chart::Fill::LinearGradient::Offset',
     default => 0,
     required => 1,
 );
 
-has 'offset2' => (
-    is => 'rw',
-    isa => 'Google::Chart::Fill::LinearGradient::Offset',
-    default => 0,
-    required => 1,
-);
 
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
-no Moose::Util::TypeConstraints;
 
 sub parameter_value {
     my $self = shift;
-    return join(",", $self->target, 'lg', $self->angle, $self->color1, $self->offset1, $self->color2, $self->offset2);
+    return join(",", $self->target, 'lg', $self->angle, $self->color, $self->offset);
 }
 
 1;
