@@ -1,4 +1,4 @@
-# $Id$
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/trunk/lib/Google/Chart/Legend.pm 67466 2008-07-30T01:53:50.528367Z daisuke  $
 
 package Google::Chart::Legend;
 use Moose;
@@ -56,7 +56,6 @@ has 'position' => (
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
-no Moose::Util::TypeConstraints;
 
 sub as_query {
     my $self = shift;
@@ -81,8 +80,4 @@ __END__
 
 Google::Chart::Legend - Google::Chart Legend
 
-=head1 METHODS
-
-=head2 as_query
-
 =cut
